* 15 February 2022
* CVACS Survey 1
* Coding employment status

*==============================================================================================================================================================

* GLOBALS FOR DATA FILES AND VERSION SUFFIXES

global CVS1DataIN "C:\Users\User\Desktop\Data"    			 //File path to where data is located. Change this path according to where your data folder is located on your computer.
global CVS1VerIN "S1_Anon_V1.0.0"

global DataOUT "C:\Users\User\Desktop\Data"
global VersionOUT "Derived"			

global temp "C:\Users\Admin\Desktop\CVACS\S1"				// tempfile to hold all the working datasets, all working datasets will
															// be deleted from this folder at the completion of the do file execution.													

version 12.0												// version of Stata being used, this is needed for the rename command.

set more off

*==============================================================================================================================================================
	
use "$CVS1DataIN\Unvaccinated_CVACS_$CVS1VerIN.dta", clear

cap rename s1_u_* *

keep if outcome == 1

*--------------------------------------------------------------------------------------------------------------------------------------------------------------
* Generating employment in the last week variable
*--------------------------------------------------------------------------------------------------------------------------------------------------------------
/*
Notes:
1) This do-file prepares the employment in the last week variable for CVACS.
2) It is not possible to create a full employment status variable, because there are no questionnaire options for unemployed/NEA in the last week.
3) Therefore, the variable created below is binary for employment only, which should be thought of as the "labour absorption rate" for the age group under consideration.

*/


/* Generating employment in the last week variable. 
There are 3 component variables:
1) emwk: Last week, did you have any kind of job for pay? (employee)
2) emswk: Last week, did you do any kind of business such as selling things - big or small - even if only for one hour? (self-employed)
3) emanywk: Last week, did you work for any profit or pay, even if just for an hour or a small amount? 

*/

gen s1_empl=.

* Step 1: Generate correct refusals & Don't knows on any of the 3 constituent variables
replace s1_empl =-9 if emwk ==-9 | emswk==-9 | emanywk==-9
replace s1_empl =-8 if emwk ==-8 | emswk==-8 | emanywk==-8
replace s1_empl =-3 if emwk ==-3 | emswk==-3 | emanywk==-3

* Step 2: Unemployed or NEA on all of the 3 variables
replace s1_empl=0 if emanywk ==2 & emswk==2 & emwk==2 
replace s1_empl=0 if emwk==3


* Step 3: Employed on any of the 3 variables
replace s1_empl=1 if emanywk ==1 | emswk==1 | emwk==1

* Step 4: Labelling the variable
cap lab var s1_empl "Employment Status: last week"
cap lab def s1_empl 1 "Employed" 0 "Not employed:i.e. Unemployed or NEA" -8 "Refused" -9 "Don't Know" -3 "Missing",add
cap lab val s1_empl s1_empl 

keep pid s1_empl

save "$DataOUT\Emp_status.dta", replace

*==============================================================================================================================================================

* end of do file

